"use client";

import { useEffect } from "react";
import Link from "next/link";
import { useRouter } from "next/navigation";
import Cookies from "js-cookie";
import { MessageCircleCode } from "lucide-react";

import { UserAuthorize } from "@/components/auth/user-authorize";

type Props = {
  searchParams: { [key: string]: string | string[] | undefined };
};

export default function AuthPage({ searchParams }: Props) {
  const router = useRouter();

  useEffect(() => {
    // 检查是否有 OAuth 状态参数
    const oauthState = Cookies.get("oauth_state");
    if (oauthState) {
      try {
        // 解码 OAuth 参数
        const params = JSON.parse(atob(oauthState));
        // 删除 cookie
        fetch("/api/auth/oauth-state", { method: "DELETE" }).catch(
          console.error,
        );
        // 构建重定向 URL
        const searchParams = new URLSearchParams(params);
        router.push(`/oauth/authorize?${searchParams.toString()}`);
      } catch (error) {
        console.error("Failed to process OAuth state:", error);
      }
    }
  }, [router]);

  return (
    <div className="mx-auto flex w-full flex-col justify-center space-y-6 sm:w-[350px]">
      <div className="flex flex-col space-y-2 text-center">
        <MessageCircleCode className="mx-auto size-12" />
        <div className="text-2xl font-semibold tracking-tight">
          <span>Welcome to</span>{" "}
          <span style={{ fontFamily: "Bahamas Bold" }}>Q58论坛</span>
        </div>
      </div>
      <div>
        <UserAuthorize data={searchParams} />
      </div>
      <p className="px-8 text-center text-sm text-muted-foreground">
        By clicking continue, you agree to our{" "}
        <Link
          href="https://q58.club/tos"
          className="hover:text-brand underline underline-offset-4"
        >
          Terms of Service
        </Link>{" "}
        and{" "}
        <Link
          href="https://q58.club/privacy"
          className="hover:text-brand underline underline-offset-4"
        >
          Privacy Policy
        </Link>
        .
      </p>
    </div>
  );
}
