"use client";

import { useEffect } from "react";
import Link from "next/link";
import { ChevronLeft, MessageCircleCode } from "lucide-react";

import { cn } from "@/lib/utils";
import { buttonVariants } from "@/components/ui/button";
import { UserAuthForm } from "@/components/auth/user-auth-form";

interface Props {
  searchParams: { state?: string };
}

export default function LoginPage({ searchParams }: Props) {
  useEffect(() => {
    // 如果有 state 参数，保存到 cookie
    if (searchParams.state) {
      fetch("/api/auth/oauth-state", {
        method: "POST",
        headers: {
          "Content-Type": "application/json",
        },
        body: JSON.stringify({ state: searchParams.state }),
      }).catch(console.error);
    }
  }, [searchParams.state]);

  return (
    <>
      <Link
        href="/"
        className={cn(
          buttonVariants({ variant: "outline", size: "sm" }),
          "absolute left-4 top-4 md:left-8 md:top-8",
        )}
      >
        <>
          <ChevronLeft className="mr-2 size-4" />
          Back
        </>
      </Link>
      <div className="mx-auto flex w-full flex-col justify-center space-y-6 sm:w-[350px]">
        <div className="flex flex-col space-y-2 text-center">
          <MessageCircleCode className="mx-auto size-12" />
          <div className="text-2xl font-semibold tracking-tight">
            <span>Welcome to</span>{" "}
            <span style={{ fontFamily: "Bahamas Bold" }}>Q58 Connect</span>
          </div>
        </div>
        <UserAuthForm />
        <p className="px-8 text-center text-sm text-muted-foreground">
          By clicking continue, you agree to our{" "}
          <Link
            href="https://q58.club/tos"
            className="hover:text-brand underline underline-offset-4"
          >
            Terms of Service
          </Link>{" "}
          and{" "}
          <Link
            href="https://q58.club/privacy"
            className="hover:text-brand underline underline-offset-4"
          >
            Privacy Policy
          </Link>
          .
        </p>
      </div>
    </>
  );
}
